==> go-test-framework-212.5080.40-sources.jar: com/goide/vgo/mod/VgoCodeInsightFixtureTestCase.java <==
// Copyright 2016-2021 JetBrains s.r.o.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// https://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
package com.goide.vgo.mod;

import com.goide.GoCodeInsightFixtureTestCase;
import com.goide.GoTestUtil;
import com.goide.vgo.VgoTestConfigurator;
import com.goide.vgo.VgoTestUtil;
import com.goide.vgo.mod.psi.VgoFile;
import com.goide.vgo.project.VgoModule;
import com.intellij.codeInsight.intention.IntentionAction;
import com.intellij.util.ObjectUtils;
import com.intellij.util.containers.ContainerUtil;
import org.jetbrains.annotations.NotNull;

import java.util.List;

abstract public class VgoCodeInsightFixtureTestCase extends GoCodeInsightFixtureTestCase {
  @Override
  protected void setUp() throws Exception {
    super.setUp();
    if (setupVgoIntegration()) {
      VgoTestUtil.setupVgoIntegration(myFixture);
    }
  }

  @Override
  protected void setupGoSupport() {
    GoTestUtil.setupGoSupport(this, getProject(), getModule(), false, "1.11");
  }

  protected boolean setupVgoIntegration() { return true; }

  protected void configureVgoModule() {
    configureVgoModule(getTestName(true));
  }

  protected @NotNull VgoModule configureVgoModule(@NotNull String testData) {
    return new VgoTestConfigurator(myFixture, testData).configure().get(0);
  }

  protected void testQuickFix(@NotNull String quickFixName) {
    myFixture.configureByFile(getTestName(true) + "/before/go.mod");
    myFixture.launchAction(myFixture.findSingleIntention(quickFixName));
    myFixture.checkResultByFile(getTestName(true) + "/after/go.mod");
  }

  protected void testQuickFix(@NotNull IntentionAction intention) {
    myFixture.configureByFile(getTestName(true) + "/before/go.mod");
    myFixture.launchAction(intention);
    myFixture.checkResultByFile(getTestName(true) + "/after/go.mod");
  }

  protected void doTestSameVariants(@NotNull String text, @NotNull String @NotNull ... expectedVariants) {
    assertSameElements(doTestCompletion(text), expectedVariants);
  }

  @NotNull
  protected VgoFile configureModuleAndGetGoModFile(@NotNull String modulePath) {
    VgoModule vgoModule = configureVgoModule(modulePath);
    return VgoTestUtil.getGoModPsiFile(myFixture, vgoModule);
  }

  @NotNull
  protected List<String> doTestCompletion(@NotNull String text) {
    myFixture.configureByText("go.mod", text);
    failOnFileLoading();
    myFixture.completeBasic();
    return ObjectUtils.notNull(myFixture.getLookupElementStrings(), ContainerUtil.emptyList());
  }

  protected void doTestCompletionResult(@NotNull String text, @NotNull String expectedTextAfterCompletion) {
    doTestCompletion(text);
    myFixture.checkResult(expectedTextAfterCompletion);
  }

  @NotNull
  @Override
  protected String getTestDataPath() {
    return VgoTestUtil.getTestDataPath(getBasePath());
  }
}

==> go-test-framework-221.5080.224-sources.jar: com/goide/vgo/mod/VgoCodeInsightFixtureTestCase.java <==
// Copyright 2016-2021 JetBrains s.r.o.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// https://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
package com.goide.vgo.mod;

import com.goide.GoCodeInsightFixtureTestCase;
import com.goide.GoTestUtil;
import com.goide.vgo.VgoTestConfigurator;
import com.goide.vgo.VgoTestUtil;
import com.goide.vgo.VgoUtil;
import com.goide.vgo.mod.psi.VgoFile;
import com.goide.vgo.project.VgoModule;
import com.intellij.codeInsight.intention.IntentionAction;
import com.intellij.util.ObjectUtils;
import com.intellij.util.containers.ContainerUtil;
import org.jetbrains.annotations.NotNull;

import java.util.List;

abstract public class VgoCodeInsightFixtureTestCase extends GoCodeInsightFixtureTestCase {
  @Override
  protected void setUp() throws Exception {
    super.setUp();
    if (setupVgoIntegration()) {
      VgoTestUtil.setupVgoIntegration(myFixture);
    }
  }

  @Override
  protected void setupGoSupport() {
    GoTestUtil.setupGoSupport(this, getProject(), getModule(), false, "1.11");
  }

  protected boolean setupVgoIntegration() { return true; }

  protected void configureVgoModule() {
    configureVgoModule(getTestName(true));
  }

  protected @NotNull VgoModule configureVgoModule(@NotNull String testData) {
    return new VgoTestConfigurator(myFixture, testData).configure().get(0);
  }

  protected void testQuickFix(@NotNull String quickFixName) {
    myFixture.configureByFile(getTestName(true) + "/before/go.mod");
    myFixture.launchAction(myFixture.findSingleIntention(quickFixName));
    myFixture.checkResultByFile(getTestName(true) + "/after/go.mod");
  }

  protected void testQuickFix(@NotNull IntentionAction intention) {
    myFixture.configureByFile(getTestName(true) + "/before/go.mod");
    myFixture.launchAction(intention);
    myFixture.checkResultByFile(getTestName(true) + "/after/go.mod");
  }

  protected void doTestSameVariants(@NotNull String text, @NotNull String @NotNull ... expectedVariants) {
    assertSameElements(doTestCompletion(text), expectedVariants);
  }

  @NotNull
  protected VgoFile configureModuleAndGetGoModFile(@NotNull String modulePath) {
    VgoModule vgoModule = configureVgoModule(modulePath);
    return VgoTestUtil.getGoModPsiFile(myFixture, vgoModule);
  }

  @NotNull
  protected List<String> doTestCompletion(@NotNull String text) {
    myFixture.configureByText(VgoUtil.GO_MOD, text);
    failOnFileLoading();
    myFixture.completeBasic();
    return ObjectUtils.notNull(myFixture.getLookupElementStrings(), ContainerUtil.emptyList());
  }

  protected void doTestCompletionResult(@NotNull String text, @NotNull String expectedTextAfterCompletion) {
    doTestCompletion(text);
    myFixture.checkResult(expectedTextAfterCompletion);
  }

  @NotNull
  @Override
  protected String getTestDataPath() {
    return VgoTestUtil.getTestDataPath(getBasePath());
  }
}
